# coding: utf-8

"""
Trading API

API for automated trading and exchange interface. This API is used to trade on the exchange and manage bots, API keys, orders, and more.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing_extensions import Self

from crypticorn.trade.client.models.exchange import Exchange


class ExchangeInfo(BaseModel):
    """
    Model for exchange info
    """  # noqa: E501

    exchange: Exchange = Field(description="Exchange")
    is_tradeable: StrictBool = Field(
        description="Whether the exchange is tradeable (trade execution is implemented)"
    )
    is_beta: StrictBool = Field(
        description="Whether the exchange is in public beta testing (marked as beta in the UI)"
    )
    is_public: StrictBool = Field(
        description="Whether the exchange is public (shown in the UI)"
    )
    is_planned: StrictBool = Field(
        description="Whether the exchange is planned to be added (marked as planned but disabled in the UI)"
    )
    is_deprecated: StrictBool = Field(
        description="Whether the exchange is deprecated (not supported anymore)"
    )
    ref_link: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = [
        "exchange",
        "is_tradeable",
        "is_beta",
        "is_public",
        "is_planned",
        "is_deprecated",
        "ref_link",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ExchangeInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if ref_link (nullable) is None
        # and model_fields_set contains the field
        if self.ref_link is None and "ref_link" in self.model_fields_set:
            _dict["ref_link"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ExchangeInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "exchange": obj.get("exchange"),
                "is_tradeable": obj.get("is_tradeable"),
                "is_beta": obj.get("is_beta"),
                "is_public": obj.get("is_public"),
                "is_planned": obj.get("is_planned"),
                "is_deprecated": obj.get("is_deprecated"),
                "ref_link": obj.get("ref_link"),
            }
        )
        return _obj
